@@ -9,7 +9,7 @@
 package Dancer::Plugin::Swagger;
 our $AUTHORITY = 'cpan:YANICK';
 # ABSTRACT: create Swagger documentation of the app REST interface 
-$Dancer::Plugin::Swagger::VERSION = '0.2.0';
+$Dancer::Plugin::Swagger::VERSION = '0.2.1';
 use strict;
 use warnings;
 
@@ -217,12 +217,16 @@ register swagger_path => sub {
                 $value->{name} = $k;
                 $k = $value;
             }
+            if (!exists($k->{schema}) && !exists($k->{type})) {
+                # set a default type iff it's missing and this doesn't reference a schema
+                $k->{type} = 'string';
+            }
             push @p, $k;
         }
         $p = \@p;
 
         # set defaults
-        $p = [ map { +{ in => 'query', type => 'string', %$_ } } @$p ];
+        $p = [ map { +{ in => 'query', %$_ } } @$p ];
         
         $arg->{parameters} = $p;
     }
@@ -295,7 +299,7 @@ Dancer::Plugin::Swagger - create Swagger documentation of the app REST interface
 
 =head1 VERSION
 
-version 0.2.0
+version 0.2.1
 
 =head1 SYNOPSIS
 
@@ -637,7 +641,7 @@ Yanick Champoux <yanick@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by Yanick Champoux.
+This software is copyright (c) 2021, 2016, 2015 by Yanick Champoux.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
